@@ -47,6 +47,7 @@ VR_sammon(double *dd, Sint *nn, Sint *kd, double *Y, Sint *niter,
 		d1 += xd * xd;
 	    }
 	    ee = d - sqrt(d1);
+	    if(d1 == 0) error("configuration has duplicates");
 	    e += (ee * ee / d);
 	}
     e /= tot;
@@ -431,25 +432,36 @@ VR_den_bin(Sint *n, Sint *nb, Sfloat *d, Sfloat *x, Sint *cnt)
     }
 }
 
-/*
 #include "R_ext/Rdynload.h"
+void
+lqs_fitlots(double *x, double *y, int *n, int *p, int *qn,
+            int *lts, int *adj, int *sample, int *nwhich,
+            int *ntrials, double *crit, int *sing, int *bestone,
+            double *bestcoef, double *pk0, double *beta);
 
-R_CMethodDef CEntries[] = {
+void
+mve_fitlots(double *x, int *n, int *p, int *qn, int *mcd,
+            int *sample, int *nwhich, int *ntrials,
+            double *crit, int *sing, int *bestone);
+
+static const R_CMethodDef CEntries[] = {
     {"VR_bcv_bin", (DL_FUNC) &VR_bcv_bin, 6},
     {"VR_den_bin", (DL_FUNC) &VR_den_bin, 5},
     {"VR_mds_dovm", (DL_FUNC) &VR_mds_dovm, 5},
-    {"VR_mds_fn", (DL_FUNC) &VR_mds_fn, 10},
-    {"VR_mds_init_data", (DL_FUNC) &VR_mds_init_data, 6},
+    {"VR_mds_fn", (DL_FUNC) &VR_mds_fn, 11},
+    {"VR_mds_init_data", (DL_FUNC) &VR_mds_init_data, 7},
     {"VR_mds_unload", (DL_FUNC) &VR_mds_unload, 0},
     {"VR_phi4_bin", (DL_FUNC) &VR_phi4_bin, 6},
     {"VR_phi6_bin", (DL_FUNC) &VR_phi6_bin, 6},
     {"VR_sammon", (DL_FUNC) &VR_sammon, 9},
     {"VR_ucv_bin", (DL_FUNC) &VR_ucv_bin, 6},
+    {"lqs_fitlots", (DL_FUNC) &lqs_fitlots, 16},
+    {"mve_fitlots", (DL_FUNC) &mve_fitlots, 11},
     {NULL, NULL, 0}
 };
 
 void R_init_MASS(DllInfo *dll)
 {
     R_registerRoutines(dll, CEntries, NULL, NULL, NULL);
+    R_useDynamicSymbols(dll, FALSE);
 }
-*/
